@@ -1,5 +1,8 @@
 #' Calculate glyph positions for strings
 #'
+#' @description
+#' `r lifecycle::badge('experimental')`
+#'
 #' Do basic text shaping of strings. This function will use freetype to
 #' calculate advances, doing kerning if possible. It will not perform any font
 #' substitution or ligature resolving and will thus be much in line with how
@@ -137,6 +140,7 @@ shape_text <- function(strings, id = NULL, family = '', italic = FALSE,
     as.numeric(indent), as.numeric(hanging), as.numeric(space_before),
     as.numeric(space_after)
   )
+  if (nrow(shape$shape) == 0) return(shape)
 
   shape$metrics$string <- vapply(split(strings, id), paste, character(1), collapse = '')
   shape$shape$string_id <- ido[shape$shape$string_id]
